# -*- coding: utf-8 -*-

from __future__ import division

import random

from utils.algorithm.b64 import b64_decrypt, b64_encrypt
from utils.algorithm.rsalg import rsa_decrypt, rsa_encrypt
from utils.error.response_utils import response


CIPHER_ALGORITHM = ('B64', 'RSA')

CIPHER_PREFIX = {
    'B64': 'alg1',
    'RSA': 'alg2',
}


def encrypt(request):
    plaintext = request.POST.get('plaintext', '')

    alg = random.choice(CIPHER_ALGORITHM)

    if alg == 'B64':
        ciphertext = b64_encrypt(plaintext)
    elif alg == 'RSA':
        ciphertext = rsa_encrypt(plaintext)
    else:
        ciphertext = plaintext

    return response(200, data={
        'ciphertext': u'%s+%s' % (CIPHER_PREFIX.get(alg, ''), ciphertext),
    })


def decrypt(request):
    ciphertext = request.POST.get('ciphertext', '')

    alg, ciphertext = ciphertext.split('+', 1)

    if alg == CIPHER_PREFIX['B64']:
        plaintext = b64_decrypt(ciphertext)
    elif alg == CIPHER_PREFIX['RSA']:
        plaintext = rsa_decrypt(ciphertext)
    else:
        plaintext = ciphertext

    return response(200, data={
        'plaintext': plaintext,
    })
